@@ -1,8 +1,12 @@
+import atexit
+import readline
 import shlex
 import sys
+from typing import cast
 
 from dmoj.error import InvalidCommandException
 from dmoj.judge import Judge
+from dmoj.packet import PacketManager
 from dmoj.utils.ansi import ansi_style, print_ansi
 
 
@@ -43,7 +47,7 @@ class LocalPacketManager:
     def current_submission_packet(self):
         pass
 
-    def submission_terminated_packet(self):
+    def submission_aborted_packet(self):
         pass
 
     def submission_acknowledged_packet(self, sub_id):
@@ -58,8 +62,7 @@ class LocalPacketManager:
 
 class LocalJudge(Judge):
     def __init__(self):
-        super().__init__()
-        self.packet_manager = LocalPacketManager(self)
+        super().__init__(cast(PacketManager, LocalPacketManager(self)))
         self.submission_id_counter = 0
         self.graded_submissions = []
 
@@ -81,6 +84,12 @@ def cli_main():
     executors.load_executors()
     contrib.load_contrib_modules()
 
+    try:
+        readline.read_history_file(judgeenv.cli_history_file)
+    except FileNotFoundError:
+        pass
+    atexit.register(readline.write_history_file, judgeenv.cli_history_file)
+
     print('Running local judge...')
 
     judge = LocalJudge()
@@ -113,20 +122,19 @@ def cli_main():
             print()
             return 127
 
-    with judge:
-        try:
-            judge.listen()
+    try:
+        judge.listen()
 
-            if judgeenv.cli_command:
-                return run_command(judgeenv.cli_command)
-            else:
-                while True:
-                    command = input(ansi_style("#ansi[dmoj](magenta)#ansi[>](green) ")).strip()
-                    run_command(shlex.split(command))
-        except (EOFError, KeyboardInterrupt):
-            print()
-        finally:
-            judge.murder()
+        if judgeenv.cli_command:
+            return run_command(judgeenv.cli_command)
+        else:
+            while True:
+                command = input(ansi_style("#ansi[dmoj](magenta)#ansi[>](green) ")).strip()
+                run_command(shlex.split(command))
+    except (EOFError, KeyboardInterrupt):
+        print()
+    finally:
+        judge.murder()
 
 
 if __name__ == '__main__':
