@@ -11,9 +11,13 @@ def errno_handler(code):
         def on_return():
             debugger.result = -code
 
-        debugger.syscall = debugger.getpid_syscall
+        debugger.syscall = -1
         debugger.on_return(on_return)
         return True
+
     return handler
 
-ACCESS_DENIED = errno_handler(errno.EACCES)
+
+for err in dir(errno):
+    if err[0] == 'E':
+        globals()['ACCESS_%s' % err] = errno_handler(getattr(errno, err))
