@@ -4,7 +4,7 @@ from .gcc_executor import GCCExecutor
 class Executor(GCCExecutor):
     name = 'F95'
     command = 'gfortran'
-    ext = '.f95'
+    ext = 'f95'
     test_program = '''\
 character(100) :: line
 read(*,'(A)') line
