@@ -2,7 +2,7 @@ from dmoj.executors.mono_executor import MonoExecutor
 
 
 class Executor(MonoExecutor):
-    ext = '.fs'
+    ext = 'fs'
     name = 'MONOFS'
     command = 'fsharpc'
     compiler_time_limit = 20
@@ -17,12 +17,18 @@ let main argv =
 '''
 
     def get_compile_args(self):
-        return [self.get_command(), '--nologo', '--optimize', '--tailcalls', '--out:%s' % self.get_compiled_file(),
-                self._code]
+        return [
+            self.get_command(),
+            '--nologo',
+            '--optimize',
+            '--tailcalls',
+            '--out:%s' % self.get_compiled_file(),
+            self._code,
+        ]
 
     @classmethod
     def get_version_flags(cls, command):
-        return ['--help'] if command == cls.command else super(Executor, cls).get_version_flags(command)
+        return ['--help'] if command == cls.command else super().get_version_flags(command)
 
     @classmethod
     def get_versionable_commands(cls):
