@@ -4,9 +4,10 @@ from dmoj.executors.mono_executor import MonoExecutor
 
 
 class Executor(MonoExecutor):
-    ext = '.vb'
+    ext = 'vb'
     name = 'MONOVB'
     command = 'mono-vbnc'
+    compile_output_index = 0
 
     test_program = '''\
 Imports System
@@ -24,20 +25,16 @@ End Module
     def get_compile_popen_kwargs(self):
         return {'stdout': subprocess.PIPE, 'stderr': subprocess.STDOUT}
 
-    def get_compile_output(self, process):
-        return process.communicate()[0]
-
     @classmethod
     def get_versionable_commands(cls):
         return ('vbnc', cls.runtime_dict['mono-vbnc']), ('mono', cls.runtime_dict['mono'])
 
     @classmethod
     def get_version_flags(cls, command):
-        return ['/help'] if command == 'vbnc' else super(Executor, cls).get_version_flags(command)
+        return ['/help'] if command == 'vbnc' else super().get_version_flags(command)
 
     @classmethod
     def get_find_first_mapping(cls):
-        res = super(Executor, cls).get_find_first_mapping()
+        res = super().get_find_first_mapping()
         res['mono-vbnc'] = ['mono-vbnc', 'vbnc']
         return res
-
