@@ -1,10 +1,9 @@
 import os
 
 from dmoj.executors.compiled_executor import CompiledExecutor
-from dmoj.executors.mixins import ScriptDirectoryMixin
 
 
-class Executor(ScriptDirectoryMixin, CompiledExecutor):
+class Executor(CompiledExecutor):
     ext = 'rkt'
     name = 'RKT'
     fs = [os.path.expanduser(r'~/\.racket/.*?'), '/etc/racket/.*?']
@@ -25,7 +24,7 @@ class Executor(ScriptDirectoryMixin, CompiledExecutor):
     def get_compile_args(self):
         return [self.runtime_dict['raco'], 'make', self._code]
 
-    def get_cmdline(self):
+    def get_cmdline(self, **kwargs):
         return [self.get_command(), self._code]
 
     def get_executable(self):
