@@ -1,10 +1,10 @@
 import subprocess
 
-from dmoj.executors.base_executor import ScriptExecutor
-import os
+from dmoj.executors.script_executor import ScriptExecutor
+
 
 class Executor(ScriptExecutor):
-    ext = '.tcl'
+    ext = 'tcl'
     name = 'TCL'
     nproc = -1  # TCL uses a bunch of threads internally
     address_grace = 131072
@@ -26,5 +26,4 @@ puts $input
         process.stdin.write(b'puts $tcl_version\n')
         process.stdin.close()
         retcode = process.poll()
-        return ('tclsh', tuple(map(int, process.stdout.read().split(b'.'))) if not retcode else ()),
-
+        return (('tclsh', tuple(map(int, process.stdout.read().split(b'.'))) if not retcode else ()),)
