@@ -4,6 +4,7 @@ from collections import deque
 from typing import Dict, List
 
 from dmoj.executors.compiled_executor import CompiledExecutor
+from dmoj.executors.mixins import SingleDigitVersionMixin
 from dmoj.judgeenv import env
 from dmoj.utils.unicode import utf8bytes, utf8text
 
@@ -15,23 +16,22 @@ MAX_ERRORS = 5
 recppexc = re.compile(br"terminate called after throwing an instance of \'([A-Za-z0-9_:]+)\'\r?$", re.M)
 
 
-class GCCExecutor(CompiledExecutor):
+class GCCExecutor(SingleDigitVersionMixin, CompiledExecutor):
     defines: List[str] = []
     flags: List[str] = []
     name = 'GCC'
     arch = 'gcc_target_arch'
     has_color = False
-    version_regex = re.compile(r'.*?(\d+(?:\.\d+)*)', re.DOTALL)
 
     source_dict: Dict[str, bytes] = {}
 
     def __init__(self, problem_id, main_source, **kwargs):
-        super().__init__(problem_id, main_source, **kwargs)
-
-        self.source_dict = kwargs.get('aux_sources', {})
+        self.source_dict = kwargs.pop('aux_sources', {})
         if main_source:
             self.source_dict[problem_id + self.ext] = main_source
-        self.defines = kwargs.get('defines', [])
+        self.defines = kwargs.pop('defines', [])
+
+        super().__init__(problem_id, main_source, **kwargs)
 
     def create_files(self, problem_id, main_source, **kwargs):
         self.source_paths = []
