@@ -4,11 +4,11 @@ import re
 import subprocess
 import sys
 from collections import deque
-from subprocess import Popen
 from typing import Optional
 
 from dmoj.error import CompileError, InternalError
 from dmoj.executors.compiled_executor import CompiledExecutor
+from dmoj.executors.mixins import SingleDigitVersionMixin
 from dmoj.judgeenv import skip_self_test
 from dmoj.utils.unicode import utf8bytes, utf8text
 
@@ -16,7 +16,7 @@ recomment = re.compile(r'/\*.*?\*/', re.DOTALL | re.U)
 restring = re.compile(r''''(?:\\.|[^'\\])'|"(?:\\.|[^"\\])*"''', re.DOTALL | re.U)
 reinline_comment = re.compile(r'//.*?(?=[\r\n])', re.U)
 reclass = re.compile(
-    r'\bpublic\s+(?:strictfp\s+)?(?:(?:abstract|final)\s+)?(?:strictfp\s+)?class\s+([\w\$][\w\$]*?)\b', re.U
+    r'\bpublic\s+(?:strictfp\s+)?(?:(?:abstract|final)\s+)?(?:strictfp\s+)?class\s+([\w$][\w$]*?)\b', re.U
 )
 repackage = re.compile(r'\bpackage\s+([^.;]+(?:\.[^.;]+)*?);', re.U)
 reexception = re.compile(r'7257b50d-e37a-4664-b1a5-b1340b4206c0: (.*?)$', re.U | re.M)
@@ -38,7 +38,7 @@ def find_class(source):
     return class_name
 
 
-class JavaExecutor(CompiledExecutor):
+class JavaExecutor(SingleDigitVersionMixin, CompiledExecutor):
     ext = 'java'
 
     vm: str
@@ -74,7 +74,7 @@ class JavaExecutor(CompiledExecutor):
     def get_executable(self):
         return self.get_vm()
 
-    def get_cmdline(self):
+    def get_cmdline(self, **kwargs):
         agent_flags = '-javaagent:%s=policy:%s' % (self._agent_file, self._policy_file)
         for hint in self._hints:
             agent_flags += ',%s' % hint
@@ -86,25 +86,16 @@ class JavaExecutor(CompiledExecutor):
             self.get_vm_mode(),
             agent_flags,
             '-Xss128m',
-            '-Xmx%dK' % self.__memory_limit,
+            '-Xmx%dK' % kwargs['orig_memory'],
             '-XX:+UseSerialGC',
             '-XX:ErrorFile=submission_jvm_crash.log',
             self._class_name,
         ]
 
     def launch(self, *args, **kwargs):
-        self.__memory_limit = kwargs['memory']
-        kwargs['memory'] = 0
+        kwargs['orig_memory'], kwargs['memory'] = kwargs['memory'], 0
         return super().launch(*args, **kwargs)
 
-    def launch_unsafe(self, *args, **kwargs):
-        return Popen(
-            ['java', self.get_vm_mode(), self._class_name] + list(args),
-            executable=self.get_vm(),
-            cwd=self._dir,
-            **kwargs
-        )
-
     def parse_feedback_from_stderr(self, stderr, process):
         if process.returncode:
             try:
