@@ -18,7 +18,7 @@ BASE_FILESYSTEM = [
     '/lib(?:32|64)?/',
     '/opt/',
     '/etc$',
-    '/etc/(?:localtime|timezone|nsswitch.conf|resolv.conf|passwd|malloc.conf)$',
+    '/etc/(?:localtime|timezone)$',
     '/usr$',
     '/tmp$',
     '/$',
@@ -114,7 +114,7 @@ class PlatformExecutorMixin(metaclass=abc.ABCMeta):
         env.update(self.get_env())
 
         return TracedPopen(
-            [utf8bytes(a) for a in self.get_cmdline() + list(args)],
+            [utf8bytes(a) for a in self.get_cmdline(**kwargs) + list(args)],
             executable=utf8bytes(self.get_executable()),
             security=self.get_security(launch_kwargs=kwargs),
             address_grace=self.get_address_grace(),
@@ -155,11 +155,5 @@ class NullStdoutMixin:
         return result
 
 
-class ScriptDirectoryMixin:
-    """
-    Certain script executors need access to the entire directory of the script,
-    usually for some searching purposes.
-    """
-
-    def get_fs(self):
-        return super().get_fs() + [self._dir]
+class SingleDigitVersionMixin:
+    version_regex = re.compile(r'.*?(\d+(?:\.\d+)*)', re.DOTALL)
