@@ -2,13 +2,12 @@ import re
 from collections import deque
 
 from dmoj.executors.compiled_executor import CompiledExecutor
-from dmoj.executors.mixins import ScriptDirectoryMixin
 from dmoj.utils.unicode import utf8bytes, utf8text
 
 retraceback = re.compile(r'Traceback \(most recent call last\):\n.*?\n([a-zA-Z_]\w*)(?::[^\n]*?)?$', re.S | re.M)
 
 
-class PythonExecutor(ScriptDirectoryMixin, CompiledExecutor):
+class PythonExecutor(CompiledExecutor):
     loader_script = '''\
 import runpy, sys, os
 del sys.argv[0]
@@ -28,7 +27,7 @@ runpy.run_path(sys.argv[0], run_name='__main__')
     def get_compile_args(self):
         return [self.get_command(), '-m', 'compileall', '-q', self._dir]
 
-    def get_cmdline(self):
+    def get_cmdline(self, **kwargs):
         # -B: Don't write .pyc/.pyo, since sandbox will kill those writes
         # -S: Disable site module for speed (no loading dist-packages nor site-packages)
         return [self.get_command(), '-BS' + ('u' if self.unbuffered else ''), self._loader, self._code]
