@@ -45,7 +45,7 @@ class Problem:
                 doc,
                 defaults={
                     'wall_time_factor': 3,
-                    'output_prefix_length': 64,
+                    'output_prefix_length': 0 if 'signature_grader' in doc else 64,
                     'output_limit_length': 25165824,
                     'binary_data': False,
                     'short_circuit': True,
@@ -150,7 +150,7 @@ class Problem:
             self._problem_file_list(),
             re.compile(get_with_default('input_format', DEFAULT_TEST_CASE_INPUT_PATTERN), re.IGNORECASE),
             re.compile(get_with_default('output_format', DEFAULT_TEST_CASE_OUTPUT_PATTERN), re.IGNORECASE),
-            iter(get_with_default('case_points', itertools.repeat(1))),
+            iter(get_with_default('case_points', itertools.repeat(self.config.points))),
         )
 
     def load_checker(self, name):
@@ -159,6 +159,19 @@ class Problem:
         self._checkers[name] = checker = load_module_from_file(os.path.join(self.root_dir, name))
         return checker
 
+    @property
+    def grader_class(self):
+        from dmoj import graders
+
+        if 'custom_judge' in self.config:
+            return graders.CustomGrader
+        elif 'signature_grader' in self.config:
+            return graders.SignatureGrader
+        elif 'interactive' in self.config:
+            return graders.BridgedInteractiveGrader
+        else:
+            return graders.StandardGrader
+
     def _resolve_archive_files(self):
         if self.config.archive:
             archive_path = os.path.join(self.root_dir, self.config.archive)
@@ -360,3 +373,14 @@ class TestCase:
 
     def __str__(self):
         return 'TestCase{in=%s,out=%s,points=%s}' % (self.config['in'], self.config['out'], self.config['points'])
+
+    # FIXME(tbrindus): this is a hack working around the fact we can't pickle these fields, but we do need parts of
+    # TestCase itself on the other end of the IPC.
+    _pickle_blacklist = ('_generated', 'config', 'problem')
+
+    def __getstate__(self):
+        k = {k: v for k, v in self.__dict__.items() if k not in self._pickle_blacklist}
+        return k
+
+    def __setstate__(self, state):
+        self.__dict__.update(state)
